@@ -16,10 +16,11 @@
 # Copyright (c) 2020 wtracy <afishionado@gmail.com>
 # Copyright (c) 2020 Anthony Sottile <asottile@umich.edu>
 # Copyright (c) 2020 Benny <benny.mueller91@gmail.com>
+# Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
 # Copyright (c) 2021 Konstantina Saketou <56515303+ksaketou@users.noreply.github.com>
 
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
-# For details: https://github.com/PyCQA/pylint/blob/master/COPYING
+# For details: https://github.com/PyCQA/pylint/blob/master/LICENSE
 
 
 """Check source code is ascii only or has an encoding declaration (PEP 263)"""
@@ -38,7 +39,6 @@ class ByIdManagedMessagesChecker(BaseChecker):
     """Checks for messages that are enabled or disabled by id instead of symbol."""
 
     __implements__ = IRawChecker
-
     name = "miscellaneous"
     msgs = {
         "I0023": (
@@ -47,7 +47,6 @@ class ByIdManagedMessagesChecker(BaseChecker):
             "Used when a message is enabled or disabled by id.",
         )
     }
-
     options = ()
 
     def process_module(self, module):
@@ -106,7 +105,7 @@ class EncodingChecker(BaseChecker):
     def open(self):
         super().open()
 
-        notes = "|".join(map(re.escape, self.config.notes))
+        notes = "|".join(re.escape(note) for note in self.config.notes)
         if self.config.notes_rgx:
             regex_string = fr"#\s*({notes}|{self.config.notes_rgx})\b"
         else:
