@@ -1,11 +1,12 @@
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
-# For details: https://github.com/PyCQA/pylint/blob/master/COPYING
+# For details: https://github.com/PyCQA/pylint/blob/master/LICENSE
 
 import os
 import sys
 import warnings
 
 from pylint import __pkginfo__, config, extensions, interfaces
+from pylint.constants import full_version
 from pylint.lint.pylinter import PyLinter
 from pylint.lint.utils import ArgumentPreprocessingError, preprocess_options
 from pylint.utils import utils
@@ -33,7 +34,7 @@ def cb_list_extensions(option, optname, value, parser):
     for filename in os.listdir(os.path.dirname(extensions.__file__)):
         if filename.endswith(".py") and not filename.startswith("_"):
             extension_name, _, _ = filename.partition(".")
-            print("pylint.extensions.{}".format(extension_name))
+            print(f"pylint.extensions.{extension_name}")
     sys.exit(0)
 
 
@@ -71,9 +72,15 @@ group are mutually exclusive.",
         return 1
 
     def __init__(
-        self, args, reporter=None, exit=True, do_exit=UNUSED_PARAM_SENTINEL,
+        self,
+        args,
+        reporter=None,
+        exit=True,
+        do_exit=UNUSED_PARAM_SENTINEL,
     ):  # pylint: disable=redefined-builtin
         self._rcfile = None
+        self._output = None
+        self._version_asked = False
         self._plugins = []
         self.verbose = None
         try:
@@ -81,10 +88,12 @@ group are mutually exclusive.",
                 args,
                 {
                     # option: (callback, takearg)
+                    "version": (self.version_asked, False),
                     "init-hook": (cb_init_hook, True),
                     "rcfile": (self.cb_set_rcfile, True),
                     "load-plugins": (self.cb_add_plugins, True),
                     "verbose": (self.cb_verbose_mode, False),
+                    "output": (self.cb_set_output, True),
                 },
             )
         except ArgumentPreprocessingError as ex:
@@ -104,6 +113,17 @@ group are mutually exclusive.",
                         "help": "Specify a configuration file to load.",
                     },
                 ),
+                (
+                    "output",
+                    {
+                        "action": "callback",
+                        "callback": Run._return_one,
+                        "group": "Commands",
+                        "type": "string",
+                        "metavar": "<file>",
+                        "help": "Specify an output file.",
+                    },
+                ),
                 (
                     "init-hook",
                     {
@@ -251,12 +271,14 @@ group are mutually exclusive.",
             pylintrc=self._rcfile,
         )
         # register standard checkers
+        if self._version_asked:
+            print(full_version)
+            sys.exit(0)
         linter.load_default_plugins()
         # load command line plugins
         linter.load_plugin_modules(self._plugins)
         # add some help section
         linter.add_help_section("Environment variables", config.ENV_HELP, level=1)
-        # pylint: disable=bad-continuation
         linter.add_help_section(
             "Output",
             "Using the default text output, the message format is :                          \n"
@@ -290,7 +312,12 @@ group are mutually exclusive.",
         # read configuration
         linter.disable("I")
         linter.enable("c-extension-no-member")
-        linter.read_config_file(verbose=self.verbose)
+        try:
+            linter.read_config_file(verbose=self.verbose)
+        except OSError as ex:
+            print(ex, file=sys.stderr)
+            sys.exit(32)
+
         config_parser = linter.cfgfile_parser
         # run init hook, if present, before loading plugins
         if config_parser.has_option("MASTER", "init-hook"):
@@ -330,7 +357,7 @@ group are mutually exclusive.",
         if linter.config.jobs > 1 or linter.config.jobs == 0:
             if multiprocessing is None:
                 print(
-                    "Multiprocessing library is missing, " "fallback to single process",
+                    "Multiprocessing library is missing, fallback to single process",
                     file=sys.stderr,
                 )
                 linter.set_option("jobs", 1)
@@ -341,8 +368,18 @@ group are mutually exclusive.",
         # load plugin specific configuration.
         linter.load_plugin_configuration()
 
-        linter.check(args)
-        score_value = linter.generate_reports()
+        if self._output:
+            try:
+                with open(self._output, "w") as output:
+                    linter.reporter.set_output(output)
+                    linter.check(args)
+                    score_value = linter.generate_reports()
+            except OSError as ex:
+                print(ex, file=sys.stderr)
+                sys.exit(32)
+        else:
+            linter.check(args)
+            score_value = linter.generate_reports()
 
         if do_exit is not UNUSED_PARAM_SENTINEL:
             warnings.warn(
@@ -355,14 +392,22 @@ group are mutually exclusive.",
             if linter.config.exit_zero:
                 sys.exit(0)
             else:
-                if score_value and score_value > linter.config.fail_under:
+                if score_value and score_value >= linter.config.fail_under:
                     sys.exit(0)
                 sys.exit(self.linter.msg_status)
 
+    def version_asked(self, _, __):
+        """callback for version (i.e. before option parsing)"""
+        self._version_asked = True
+
     def cb_set_rcfile(self, name, value):
         """callback for option preprocessing (i.e. before option parsing)"""
         self._rcfile = value
 
+    def cb_set_output(self, name, value):
+        """callback for option preprocessing (i.e. before option parsing)"""
+        self._output = value
+
     def cb_add_plugins(self, name, value):
         """callback for option preprocessing (i.e. before option parsing)"""
         self._plugins.extend(utils._splitstrip(value))
