@@ -1,10 +1,13 @@
-# Copyright (c) 2015-2016 Claudiu Popa <pcmanticore@gmail.com>
+# Copyright (c) 2015-2016, 2018, 2020 Claudiu Popa <pcmanticore@gmail.com>
 # Copyright (c) 2018 ssolanki <sushobhitsolanki@gmail.com>
 # Copyright (c) 2018 Sushobhit <31987769+sushobhit27@users.noreply.github.com>
 # Copyright (c) 2018 Nick Drozd <nicholasdrozd@gmail.com>
+# Copyright (c) 2020 hippo91 <guillaume.peillex@gmail.com>
+# Copyright (c) 2020 Anthony Sottile <asottile@umich.edu>
+# Copyright (c) 2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
 
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
-# For details: https://github.com/PyCQA/pylint/blob/master/COPYING
+# For details: https://github.com/PyCQA/pylint/blob/master/LICENSE
 
 """Micro reports objects.
 
@@ -62,7 +65,7 @@ class BaseLayout(VNode):
     """
 
     def __init__(self, children=(), **kwargs):
-        super(BaseLayout, self).__init__(**kwargs)
+        super().__init__(**kwargs)
         for child in children:
             if isinstance(child, VNode):
                 self.append(child)
@@ -97,7 +100,7 @@ class Text(VNode):
     """
 
     def __init__(self, data, escaped=True, **kwargs):
-        super(Text, self).__init__(**kwargs)
+        super().__init__(**kwargs)
         # if isinstance(data, unicode):
         #    data = data.encode('ascii')
         assert isinstance(data, str), data.__class__
@@ -129,7 +132,7 @@ class Section(BaseLayout):
     """
 
     def __init__(self, title=None, description=None, **kwargs):
-        super(Section, self).__init__(**kwargs)
+        super().__init__(**kwargs)
         if description:
             self.insert(0, Paragraph([Text(description)]))
         if title:
@@ -138,7 +141,7 @@ class Section(BaseLayout):
 
 class EvaluationSection(Section):
     def __init__(self, message, **kwargs):
-        super(EvaluationSection, self).__init__(**kwargs)
+        super().__init__(**kwargs)
         title = Paragraph()
         title.append(Text("-" * len(message)))
         self.append(title)
@@ -180,7 +183,7 @@ class Table(BaseLayout):
     """
 
     def __init__(self, cols, title=None, rheaders=0, cheaders=0, **kwargs):
-        super(Table, self).__init__(**kwargs)
+        super().__init__(**kwargs)
         assert isinstance(cols, int)
         self.cols = cols
         self.title = title
