@@ -1,5 +1,5 @@
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
-# For details: https://github.com/PyCQA/pylint/blob/master/COPYING
+# For details: https://github.com/PyCQA/pylint/blob/master/LICENSE
 
 import re
 from collections import namedtuple
@@ -87,7 +87,7 @@ class InvalidPragmaError(PragmaParserError):
 
 def parse_pragma(pylint_pragma: str) -> Generator[PragmaRepresenter, None, None]:
     action = None
-    messages = []  # type: List[str]
+    messages: List[str] = []
     assignment_required = False
     previous_token = ""
 
